==> icons-vue-0.3.0.tgz: package/lib/watson-health/stress-breath-editor/16.js <==
'use strict';

var __chunk_1 = require('../../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthStressBreathEditor16 = {
  name: 'WatsonHealthStressBreathEditor16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = __chunk_1._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M20 4a5 5 0 1 1-5 5 5 5 0 0 1 5-5m0-2a7 7 0 1 0 7 7A7 7 0 0 0 20 2zM30 30H28V25a5 5 0 0 0-5-5H17a5 5 0 0 0-5 5v5H10V25a7 7 0 0 1 7-7h6a7 7 0 0 1 7 7zM11 8H5A3 3 0 0 1 2 5V3H4V5A1 1 0 0 0 5 6h6zM4 15H2V13a3 3 0 0 1 3-3h6v2H5a1 1 0 0 0-1 1z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthStressBreathEditor16;

==> icons-vue-0.6.0.tgz: package/lib/watson-health/stress-breath-editor/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthStressBreathEditor16 = {
  name: 'WatsonHealthStressBreathEditor16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M20,4a5,5,0,1,1-5,5,5,5,0,0,1,5-5m0-2a7,7,0,1,0,7,7A7,7,0,0,0,20,2Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M30,30H28V25a5,5,0,0,0-5-5H17a5,5,0,0,0-5,5v5H10V25a7,7,0,0,1,7-7h6a7,7,0,0,1,7,7Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M11,8H5A3,3,0,0,1,2,5V3H4V5A1,1,0,0,0,5,6h6Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M4,15H2V13a3,3,0,0,1,3-3h6v2H5a1,1,0,0,0-1,1Z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthStressBreathEditor16;
